@@ -17,13 +17,11 @@
 // under the License.
 // </copyright>
 
-using System.Collections.Generic;
-
 namespace OpenQA.Selenium.BiDi.Browser;
 
 internal sealed class GetClientWindowsCommand()
     : Command<Parameters, GetClientWindowsResult>(Parameters.Empty, "browser.getClientWindows");
 
-public sealed class GetClientWindowsOptions : CommandOptions;
+public sealed record GetClientWindowsOptions : CommandOptions;
 
 public sealed record GetClientWindowsResult(IReadOnlyList<ClientWindowInfo> ClientWindows) : EmptyResult;
