@@ -17,10 +17,6 @@
 // under the License.
 // </copyright>
 
-using System.Threading.Tasks;
-using System.Threading;
-using System;
-
 namespace OpenQA.Selenium.BiDi;
 
 interface ITransport : IDisposable
