@@ -17,8 +17,6 @@
 // under the License.
 // </copyright>
 
-using System.Collections.Generic;
-
 namespace OpenQA.Selenium.BiDi.Input;
 
 internal sealed class PerformActionsCommand(PerformActionsParameters @params)
@@ -26,6 +24,6 @@ internal sealed class PerformActionsCommand(PerformActionsParameters @params)
 
 internal sealed record PerformActionsParameters(BrowsingContext.BrowsingContext Context, IEnumerable<SourceActions> Actions) : Parameters;
 
-public sealed class PerformActionsOptions : CommandOptions;
+public sealed record PerformActionsOptions : CommandOptions;
 
 public sealed record PerformActionsResult : EmptyResult;
