@@ -17,8 +17,6 @@
 // under the License.
 // </copyright>
 
-using System.Collections.Generic;
-
 namespace OpenQA.Selenium.BiDi.Input;
 
 internal sealed class SetFilesCommand(SetFilesParameters @params)
@@ -26,6 +24,6 @@ internal sealed class SetFilesCommand(SetFilesParameters @params)
 
 internal sealed record SetFilesParameters(BrowsingContext.BrowsingContext Context, Script.ISharedReference Element, IEnumerable<string> Files) : Parameters;
 
-public sealed class SetFilesOptions : CommandOptions;
+public sealed record SetFilesOptions : CommandOptions;
 
 public sealed record SetFilesResult : EmptyResult;
