@@ -17,11 +17,9 @@
 // under the License.
 // </copyright>
 
+using System.Text.Json.Serialization;
 using OpenQA.Selenium.BiDi.Json.Converters;
 using OpenQA.Selenium.BiDi.Json.Converters.Polymorphic;
-using System;
-using System.Collections.Generic;
-using System.Text.Json.Serialization;
 
 namespace OpenQA.Selenium.BiDi.Log;
 
@@ -34,7 +32,7 @@ namespace OpenQA.Selenium.BiDi.Log;
 public abstract record LogEntry(Level Level, Script.Source Source, string? Text, DateTimeOffset Timestamp)
     : EventArgs
 {
-    public Script.StackTrace? StackTrace { get; set; }
+    public Script.StackTrace? StackTrace { get; init; }
 }
 
 public sealed record GenericLogEntry(string Type, Level Level, Script.Source Source, string? Text, DateTimeOffset Timestamp)
