@@ -17,9 +17,8 @@
 // under the License.
 // </copyright>
 
-using OpenQA.Selenium.BiDi.Json.Converters;
-using System.Collections.Generic;
 using System.Text.Json.Serialization;
+using OpenQA.Selenium.BiDi.Json.Converters;
 
 namespace OpenQA.Selenium.BiDi.Network;
 
@@ -28,26 +27,28 @@ internal sealed class AddDataCollectorCommand(AddDataCollectorParameters @params
 
 internal sealed record AddDataCollectorParameters(IEnumerable<DataType> DataTypes, int MaxEncodedDataSize, CollectorType? CollectorType, IEnumerable<BrowsingContext.BrowsingContext>? Contexts, IEnumerable<Browser.UserContext>? UserContexts) : Parameters;
 
-public class AddDataCollectorOptions() : CommandOptions
+public sealed record AddDataCollectorOptions : CommandOptions
 {
-    internal AddDataCollectorOptions(BrowsingContextAddDataCollectorOptions? options) : this()
-    {
-        CollectorType = options?.CollectorType;
-        UserContexts = options?.UserContexts;
-    }
+    public CollectorType? CollectorType { get; init; }
 
-    public CollectorType? CollectorType { get; set; }
+    public IEnumerable<BrowsingContext.BrowsingContext>? Contexts { get; init; }
 
-    public IEnumerable<BrowsingContext.BrowsingContext>? Contexts { get; set; }
-
-    public IEnumerable<Browser.UserContext>? UserContexts { get; set; }
+    public IEnumerable<Browser.UserContext>? UserContexts { get; init; }
 }
 
-public class BrowsingContextAddDataCollectorOptions
+public sealed record ContextAddDataCollectorOptions : CommandOptions
 {
-    public CollectorType? CollectorType { get; set; }
+    public CollectorType? CollectorType { get; init; }
 
-    public IEnumerable<Browser.UserContext>? UserContexts { get; set; }
+    public IEnumerable<Browser.UserContext>? UserContexts { get; init; }
+
+    internal static AddDataCollectorOptions WithContext(ContextAddDataCollectorOptions? options, BrowsingContext.BrowsingContext context) => new()
+    {
+        Contexts = [context],
+        CollectorType = options?.CollectorType,
+        UserContexts = options?.UserContexts,
+        Timeout = options?.Timeout
+    };
 }
 
 public sealed record AddDataCollectorResult(Collector Collector) : EmptyResult;
