@@ -17,8 +17,6 @@
 // under the License.
 // </copyright>
 
-using System.Collections.Generic;
-
 namespace OpenQA.Selenium.BiDi.Network;
 
 internal sealed class ContinueRequestCommand(ContinueRequestParameters @params)
@@ -26,17 +24,17 @@ internal sealed class ContinueRequestCommand(ContinueRequestParameters @params)
 
 internal sealed record ContinueRequestParameters(Request Request, BytesValue? Body, IEnumerable<CookieHeader>? Cookies, IEnumerable<Header>? Headers, string? Method, string? Url) : Parameters;
 
-public sealed class ContinueRequestOptions : CommandOptions
+public sealed record ContinueRequestOptions : CommandOptions
 {
-    public BytesValue? Body { get; set; }
+    public BytesValue? Body { get; init; }
 
-    public IEnumerable<CookieHeader>? Cookies { get; set; }
+    public IEnumerable<CookieHeader>? Cookies { get; init; }
 
-    public IEnumerable<Header>? Headers { get; set; }
+    public IEnumerable<Header>? Headers { get; init; }
 
-    public string? Method { get; set; }
+    public string? Method { get; init; }
 
-    public string? Url { get; set; }
+    public string? Url { get; init; }
 }
 
 public sealed record ContinueRequestResult : EmptyResult;
