@@ -17,8 +17,6 @@
 // under the License.
 // </copyright>
 
-using System.Collections.Generic;
-
 namespace OpenQA.Selenium.BiDi.Script;
 
 internal sealed class DisownCommand(DisownParameters @params)
@@ -26,6 +24,6 @@ internal sealed class DisownCommand(DisownParameters @params)
 
 internal sealed record DisownParameters(IEnumerable<Handle> Handles, Target Target) : Parameters;
 
-public sealed class DisownOptions : CommandOptions;
+public sealed record DisownOptions : CommandOptions;
 
 public sealed record DisownResult : EmptyResult;
