@@ -17,8 +17,6 @@
 // under the License.
 // </copyright>
 
-using System.Collections.Generic;
-
 namespace OpenQA.Selenium.BiDi.Script;
 
 internal sealed class GetRealmsCommand(GetRealmsParameters @params)
@@ -26,11 +24,23 @@ internal sealed class GetRealmsCommand(GetRealmsParameters @params)
 
 internal sealed record GetRealmsParameters(BrowsingContext.BrowsingContext? Context, RealmType? Type) : Parameters;
 
-public sealed class GetRealmsOptions : CommandOptions
+public sealed record GetRealmsOptions : CommandOptions
 {
-    public BrowsingContext.BrowsingContext? Context { get; set; }
+    public BrowsingContext.BrowsingContext? Context { get; init; }
 
-    public RealmType? Type { get; set; }
+    public RealmType? Type { get; init; }
+}
+
+public sealed record ContextGetRealmsOptions : CommandOptions
+{
+    public RealmType? Type { get; init; }
+
+    internal static GetRealmsOptions WithContext(ContextGetRealmsOptions? options, BrowsingContext.BrowsingContext context) => new()
+    {
+        Context = context,
+        Type = options?.Type,
+        Timeout = options?.Timeout
+    };
 }
 
 public sealed record GetRealmsResult(IReadOnlyList<RealmInfo> Realms) : EmptyResult;
