@@ -24,4 +24,4 @@ internal sealed class StatusCommand()
 
 public sealed record StatusResult(bool Ready, string Message) : EmptyResult;
 
-public sealed class StatusOptions : CommandOptions;
+public sealed record StatusOptions : CommandOptions;
