@@ -17,8 +17,6 @@
 // under the License.
 // </copyright>
 
-using System;
-using System.Collections.Generic;
 using System.Text.Json.Serialization;
 
 namespace OpenQA.Selenium.BiDi.Storage;
@@ -28,34 +26,46 @@ internal sealed class GetCookiesCommand(GetCookiesParameters @params)
 
 internal sealed record GetCookiesParameters(CookieFilter? Filter, PartitionDescriptor? Partition) : Parameters;
 
-public sealed class GetCookiesOptions : CommandOptions
+public sealed record GetCookiesOptions : CommandOptions
 {
-    public CookieFilter? Filter { get; set; }
+    public CookieFilter? Filter { get; init; }
 
-    public PartitionDescriptor? Partition { get; set; }
+    public PartitionDescriptor? Partition { get; init; }
+}
+
+public sealed record ContextGetCookiesOptions : CommandOptions
+{
+    public CookieFilter? Filter { get; init; }
+
+    internal static GetCookiesOptions WithContext(ContextGetCookiesOptions? options, BrowsingContext.BrowsingContext context) => new()
+    {
+        Filter = options?.Filter,
+        Partition = new ContextPartitionDescriptor(context),
+        Timeout = options?.Timeout
+    };
 }
 
 public sealed record GetCookiesResult(IReadOnlyList<Network.Cookie> Cookies, PartitionKey PartitionKey) : EmptyResult;
 
 public sealed record CookieFilter
 {
-    public string? Name { get; set; }
+    public string? Name { get; init; }
 
-    public Network.BytesValue? Value { get; set; }
+    public Network.BytesValue? Value { get; init; }
 
-    public string? Domain { get; set; }
+    public string? Domain { get; init; }
 
-    public string? Path { get; set; }
+    public string? Path { get; init; }
 
-    public long? Size { get; set; }
+    public long? Size { get; init; }
 
-    public bool? HttpOnly { get; set; }
+    public bool? HttpOnly { get; init; }
 
-    public bool? Secure { get; set; }
+    public bool? Secure { get; init; }
 
-    public Network.SameSite? SameSite { get; set; }
+    public Network.SameSite? SameSite { get; init; }
 
-    public DateTimeOffset? Expiry { get; set; }
+    public DateTimeOffset? Expiry { get; init; }
 }
 
 [JsonPolymorphic(TypeDiscriminatorPropertyName = "type")]
@@ -67,7 +77,7 @@ public sealed record ContextPartitionDescriptor(BrowsingContext.BrowsingContext
 
 public sealed record StorageKeyPartitionDescriptor : PartitionDescriptor
 {
-    public string? UserContext { get; set; }
+    public string? UserContext { get; init; }
 
-    public string? SourceOrigin { get; set; }
+    public string? SourceOrigin { get; init; }
 }
