@@ -17,12 +17,10 @@
 // under the License.
 // </copyright>
 
-using OpenQA.Selenium.Internal;
-using System;
-using System.Collections.Generic;
 using System.Collections.ObjectModel;
 using System.Globalization;
 using System.Text.RegularExpressions;
+using OpenQA.Selenium.Internal;
 
 namespace OpenQA.Selenium;
 
