@@ -17,10 +17,7 @@
 // under the License.
 // </copyright>
 
-using System;
-using System.Collections.Generic;
 using System.Collections.ObjectModel;
-using System.IO;
 
 namespace OpenQA.Selenium.Chromium;
 
@@ -42,7 +39,7 @@ public abstract class ChromiumOptions : DriverOptions
     private const string PerformanceLoggingPreferencesChromeOption = "perfLoggingPrefs";
     private const string WindowTypesChromeOption = "windowTypes";
     private const string UseSpecCompliantProtocolOption = "w3c";
-    private bool useSpecCompliantProtocol = true;
+    private readonly bool useSpecCompliantProtocol = true;
     private readonly List<string> arguments = new List<string>();
     private readonly List<string> extensionFiles = new List<string>();
     private readonly List<string> encodedExtensions = new List<string>();
