@@ -17,11 +17,9 @@
 // under the License.
 // </copyright>
 
-using System;
 using System.Text.Json;
 using System.Text.Json.Nodes;
 using System.Text.Json.Serialization;
-using System.Threading;
 
 namespace OpenQA.Selenium.DevTools;
 
