@@ -17,9 +17,7 @@
 // under the License.
 // </copyright>
 
-using System;
 using System.Collections.ObjectModel;
-using System.Threading.Tasks;
 
 namespace OpenQA.Selenium.DevTools;
 
@@ -84,10 +82,7 @@ public abstract class Target
     /// <param name="e">An <see cref="TargetDetachedEventArgs"/> that contains the event data.</param>
     protected virtual void OnTargetDetached(TargetDetachedEventArgs e)
     {
-        if (this.TargetDetached != null)
-        {
-            this.TargetDetached(this, e);
-        }
+        this.TargetDetached?.Invoke(this, e);
     }
 
     /// <summary>
@@ -96,9 +91,6 @@ public abstract class Target
     /// <param name="e"></param>
     protected virtual void OnTargetAttached(TargetAttachedEventArgs e)
     {
-        if (this.TargetAttached != null)
-        {
-            this.TargetAttached(this, e);
-        }
+        this.TargetAttached?.Invoke(this, e);
     }
 }
