@@ -17,23 +17,20 @@
 // under the License.
 // </copyright>
 
-using System;
+namespace OpenQA.Selenium;
 
-namespace OpenQA.Selenium
+/// <summary>
+/// Provides data for the AttributeValueChanged event
+/// </summary>
+public class DomMutatedEventArgs : EventArgs
 {
-    /// <summary>
-    /// Provides data for the AttributeValueChanged event
-    /// </summary>
-    public class DomMutatedEventArgs : EventArgs
+    internal DomMutatedEventArgs(DomMutationData attributeData)
     {
-        internal DomMutatedEventArgs(DomMutationData attributeData)
-        {
-            AttributeData = attributeData;
-        }
-
-        /// <summary>
-        /// Gets the data about the attribute being changed.
-        /// </summary>
-        public DomMutationData AttributeData { get; }
+        AttributeData = attributeData;
     }
+
+    /// <summary>
+    /// Gets the data about the attribute being changed.
+    /// </summary>
+    public DomMutationData AttributeData { get; }
 }
