@@ -17,8 +17,6 @@
 // under the License.
 // </copyright>
 
-using System.Collections.Generic;
-
 namespace OpenQA.Selenium;
 
 /// <summary>
@@ -409,6 +407,11 @@ public static class DriverCommand
     /// </summary>
     public static readonly string DeleteDownloadableFiles = "deleteDownloadableFiles";
 
+    /// <summary>
+    /// Represents the FireSessionEvent command for firing custom session events.
+    /// </summary>
+    public static readonly string FireSessionEvent = "fireSessionEvent";
+
     /// <summary>
     /// Lists the set of known commands valid for the Selenium library.
     /// </summary>
@@ -487,6 +490,7 @@ public static class DriverCommand
         SetUserVerified,
         GetDownloadableFiles,
         DownloadFile,
-        DeleteDownloadableFiles
+        DeleteDownloadableFiles,
+        FireSessionEvent
     }.AsReadOnly();
 }
