@@ -17,8 +17,6 @@
 // under the License.
 // </copyright>
 
-using System;
-using System.Collections.Generic;
 using System.Text;
 
 namespace OpenQA.Selenium.Interactions;
