@@ -17,8 +17,6 @@
 // under the License.
 // </copyright>
 
-using System;
-
 namespace OpenQA.Selenium.Internal.Logging;
 
 /// <summary>
@@ -67,8 +65,13 @@ internal sealed class Logger : ILogger
         return Log.CurrentContext.IsEnabled(this, level);
     }
 
+    public void LogMessage(DateTimeOffset timestamp, LogEventLevel level, string message)
+    {
+        Log.CurrentContext.EmitMessage(this, timestamp.ToLocalTime(), level, message);
+    }
+
     private void LogMessage(LogEventLevel level, string message)
     {
-        Log.CurrentContext.EmitMessage(this, level, message);
+        LogMessage(DateTimeOffset.Now, level, message);
     }
 }
