@@ -17,15 +17,11 @@
 // under the License.
 // </copyright>
 
-using OpenQA.Selenium.DevTools;
-using OpenQA.Selenium.Internal;
-using System;
-using System.Collections.Generic;
 using System.Diagnostics.CodeAnalysis;
 using System.Globalization;
-using System.Linq;
 using System.Text.Json;
-using System.Threading.Tasks;
+using OpenQA.Selenium.DevTools;
+using OpenQA.Selenium.Internal;
 
 namespace OpenQA.Selenium;
 
