@@ -17,10 +17,6 @@
 // under the License.
 // </copyright>
 
-using System;
-using System.Collections.Generic;
-using System.Threading.Tasks;
-
 namespace OpenQA.Selenium;
 
 /// <summary>
@@ -106,7 +102,7 @@ internal sealed class Navigator : INavigation
             throw new ArgumentNullException(nameof(url), "URL cannot be null.");
         }
 
-        Dictionary<string, object> parameters = new Dictionary<string, object>
+        Dictionary<string, object?> parameters = new Dictionary<string, object?>
         {
             { "url", url }
         };
