@@ -17,8 +17,6 @@
 // under the License.
 // </copyright>
 
-using System;
-
 namespace OpenQA.Selenium;
 
 /// <summary>
@@ -31,7 +29,7 @@ public class NoSuchDriverException : NotFoundException
     /// <summary>
     /// Link to the documentation for this error
     /// </summary>
-    private static string supportUrl = baseSupportUrl + "/driver_location";
+    private static readonly string supportUrl = baseSupportUrl + "/driver_location";
 
     /// <summary>
     /// Initializes a new instance of the <see cref="NoSuchDriverException"/> class.
