@@ -17,8 +17,6 @@
 // under the License.
 // </copyright>
 
-using System;
-using System.Collections.Generic;
 using System.Collections.ObjectModel;
 using System.Globalization;
 using System.Text.Json.Serialization;
@@ -79,7 +77,7 @@ public class Proxy
     private string? socksUserName;
     private string? socksPassword;
     private int? socksVersion;
-    private List<string> noProxyAddresses = new List<string>();
+    private readonly List<string> noProxyAddresses = new List<string>();
 
     /// <summary>
     /// Initializes a new instance of the <see cref="Proxy"/> class.
@@ -500,7 +498,7 @@ public class Proxy
 
     private object? GetNoProxyAddressList(bool isSpecCompliant)
     {
-        object? addresses = null;
+        object? addresses;
         if (isSpecCompliant)
         {
             List<object> addressList = [.. this.noProxyAddresses];
