@@ -17,13 +17,12 @@
 // under the License.
 // </copyright>
 
-using OpenQA.Selenium.Internal;
-using System;
 using System.Diagnostics.CodeAnalysis;
 using System.Globalization;
 using System.Text.Json;
 using System.Text.Json.Nodes;
 using System.Text.Json.Serialization;
+using OpenQA.Selenium.Internal;
 
 namespace OpenQA.Selenium;
 
@@ -204,5 +203,8 @@ public class Response
 }
 
 [JsonSerializable(typeof(object))]
+#pragma warning disable CS3016 // Arrays as attribute arguments is not CLS-compliant
+// This is not part of the public API, so we can ignore this warning
 [JsonSourceGenerationOptions(Converters = [typeof(ResponseValueJsonConverter)])] // we still need it to make `Object` as `Dictionary`
+#pragma warning restore CS3016 // Arrays as attribute arguments is not CLS-compliant
 internal sealed partial class ResponseJsonSerializerContext : JsonSerializerContext;
