@@ -17,11 +17,9 @@
 // under the License.
 // </copyright>
 
-using OpenQA.Selenium.Internal;
-using System;
-using System.Collections.Generic;
 using System.Collections.ObjectModel;
 using System.Diagnostics.CodeAnalysis;
+using OpenQA.Selenium.Internal;
 
 namespace OpenQA.Selenium;
 
@@ -91,7 +89,7 @@ public class ShadowRoot : ISearchContext, IWrapsDriver, IWebDriverObjectReferenc
             throw new ArgumentNullException(nameof(by), "by cannot be null");
         }
 
-        Dictionary<string, object> parameters = new Dictionary<string, object>();
+        Dictionary<string, object?> parameters = new Dictionary<string, object?>();
         parameters.Add("id", this.shadowRootId);
         parameters.Add("using", by.Mechanism);
         parameters.Add("value", by.Criteria);
@@ -115,7 +113,7 @@ public class ShadowRoot : ISearchContext, IWrapsDriver, IWebDriverObjectReferenc
             throw new ArgumentNullException(nameof(by), "by cannot be null");
         }
 
-        Dictionary<string, object> parameters = new Dictionary<string, object>();
+        Dictionary<string, object?> parameters = new Dictionary<string, object?>();
         parameters.Add("id", this.shadowRootId);
         parameters.Add("using", by.Mechanism);
         parameters.Add("value", by.Criteria);
