@@ -17,16 +17,13 @@
 // under the License.
 // </copyright>
 
-using OpenQA.Selenium.Interactions;
-using OpenQA.Selenium.Internal;
-using OpenQA.Selenium.VirtualAuth;
-using System;
 using System.Collections;
-using System.Collections.Generic;
 using System.Collections.ObjectModel;
 using System.Diagnostics.CodeAnalysis;
 using System.Globalization;
-using System.Threading.Tasks;
+using OpenQA.Selenium.Interactions;
+using OpenQA.Selenium.Internal;
+using OpenQA.Selenium.VirtualAuth;
 
 namespace OpenQA.Selenium;
 
@@ -53,6 +50,16 @@ public class WebDriver : IWebDriver, ISearchContext, IJavaScriptExecutor, IFinds
     protected WebDriver(ICommandExecutor executor, ICapabilities capabilities)
     {
         this.CommandExecutor = executor;
+        this.elementFactory = new WebElementFactory(this);
+        this.registeredCommands.AddRange(DriverCommand.KnownCommands);
+
+        if (this is ISupportsLogs)
+        {
+            // Only add the legacy log commands if the driver supports
+            // retrieving the logs via the extension end points.
+            this.RegisterDriverCommand(DriverCommand.GetAvailableLogTypes, new HttpCommandInfo(HttpCommandInfo.GetCommand, "/session/{sessionId}/se/log/types"), true);
+            this.RegisterDriverCommand(DriverCommand.GetLog, new HttpCommandInfo(HttpCommandInfo.PostCommand, "/session/{sessionId}/se/log"), true);
+        }
 
         try
         {
@@ -63,7 +70,7 @@ public class WebDriver : IWebDriver, ISearchContext, IJavaScriptExecutor, IFinds
             try
             {
                 // Failed to start driver session, disposing of driver
-                this.Quit();
+                this.Dispose();
             }
             catch
             {
@@ -71,17 +78,6 @@ public class WebDriver : IWebDriver, ISearchContext, IJavaScriptExecutor, IFinds
             }
             throw;
         }
-
-        this.elementFactory = new WebElementFactory(this);
-        this.registeredCommands.AddRange(DriverCommand.KnownCommands);
-
-        if (this is ISupportsLogs)
-        {
-            // Only add the legacy log commands if the driver supports
-            // retrieving the logs via the extension end points.
-            this.RegisterDriverCommand(DriverCommand.GetAvailableLogTypes, new HttpCommandInfo(HttpCommandInfo.GetCommand, "/session/{sessionId}/se/log/types"), true);
-            this.RegisterDriverCommand(DriverCommand.GetLog, new HttpCommandInfo(HttpCommandInfo.PostCommand, "/session/{sessionId}/se/log"), true);
-        }
     }
 
     /// <summary>
@@ -297,7 +293,7 @@ public class WebDriver : IWebDriver, ISearchContext, IJavaScriptExecutor, IFinds
     /// <returns>The first <see cref="IWebElement"/> matching the given criteria.</returns>
     public virtual IWebElement FindElement(string mechanism, string value)
     {
-        Dictionary<string, object> parameters = new Dictionary<string, object>();
+        Dictionary<string, object?> parameters = new Dictionary<string, object?>();
         parameters.Add("using", mechanism);
         parameters.Add("value", value);
 
@@ -335,7 +331,7 @@ public class WebDriver : IWebDriver, ISearchContext, IJavaScriptExecutor, IFinds
     /// <returns>A collection of all of the <see cref="IWebElement">IWebElements</see> matching the given criteria.</returns>
     public virtual ReadOnlyCollection<IWebElement> FindElements(string mechanism, string value)
     {
-        Dictionary<string, object> parameters = new Dictionary<string, object>();
+        Dictionary<string, object?> parameters = new Dictionary<string, object?>();
         parameters.Add("using", mechanism);
         parameters.Add("value", value);
 
@@ -394,7 +390,7 @@ public class WebDriver : IWebDriver, ISearchContext, IJavaScriptExecutor, IFinds
             objectList.Add(sequence.ToDictionary());
         }
 
-        Dictionary<string, object> parameters = new Dictionary<string, object>();
+        Dictionary<string, object?> parameters = new Dictionary<string, object?>();
         parameters["actions"] = objectList;
 
         this.Execute(DriverCommand.Actions, parameters);
@@ -458,7 +454,7 @@ public class WebDriver : IWebDriver, ISearchContext, IJavaScriptExecutor, IFinds
     /// <param name="parameters">A <see cref="Dictionary{K, V}"/> containing the names and values of the parameters of the command.</param>
     /// <returns>A <see cref="Response"/> containing information about the success or failure of the command and any data returned by the command.</returns>
     /// <exception cref="WebDriverException">The command returned an exceptional value.</exception>
-    public object? ExecuteCustomDriverCommand(string driverCommandToExecute, Dictionary<string, object> parameters)
+    public object? ExecuteCustomDriverCommand(string driverCommandToExecute, Dictionary<string, object?> parameters)
     {
         if (this.registeredCommands.Contains(driverCommandToExecute))
         {
@@ -558,11 +554,7 @@ public class WebDriver : IWebDriver, ISearchContext, IJavaScriptExecutor, IFinds
     /// <param name="parameters">A <see cref="Dictionary{K, V}"/> containing the names and values of the parameters of the command.</param>
     /// <returns>A <see cref="Response"/> containing information about the success or failure of the command and any data returned by the command.</returns>
     /// <exception cref="ArgumentNullException">If <paramref name="driverCommandToExecute"/> is <see langword="null"/>.</exception>
-    protected internal virtual Response Execute(string driverCommandToExecute, Dictionary<string,
-#nullable disable
-        object
-#nullable enable
-        >? parameters)
+    protected internal virtual Response Execute(string driverCommandToExecute, Dictionary<string, object?>? parameters)
     {
         return Task.Run(() => this.ExecuteAsync(driverCommandToExecute, parameters)).GetAwaiter().GetResult();
     }
@@ -574,11 +566,7 @@ public class WebDriver : IWebDriver, ISearchContext, IJavaScriptExecutor, IFinds
     /// <param name="parameters">A <see cref="Dictionary{K, V}"/> containing the names and values of the parameters of the command.</param>
     /// <returns>A <see cref="Response"/> containing information about the success or failure of the command and any data returned by the command.</returns>
     /// <exception cref="ArgumentNullException">If <paramref name="driverCommandToExecute"/> is <see langword="null"/>.</exception>
-    protected internal virtual async Task<Response> ExecuteAsync(string driverCommandToExecute, Dictionary<string,
-#nullable disable
-        object
-#nullable enable
-        >? parameters)
+    protected internal virtual async Task<Response> ExecuteAsync(string driverCommandToExecute, Dictionary<string, object?>? parameters)
     {
         Command commandToExecute = new Command(SessionId, driverCommandToExecute, parameters);
 
@@ -600,7 +588,7 @@ public class WebDriver : IWebDriver, ISearchContext, IJavaScriptExecutor, IFinds
     [MemberNotNull(nameof(Capabilities))]
     protected void StartSession(ICapabilities capabilities)
     {
-        Dictionary<string, object> parameters = new Dictionary<string, object>();
+        Dictionary<string, object?> parameters = new Dictionary<string, object?>();
 
         // If the object passed into the RemoteWebDriver constructor is a
         // RemoteSessionSettings object, it is expected that all intermediate
@@ -838,7 +826,7 @@ public class WebDriver : IWebDriver, ISearchContext, IJavaScriptExecutor, IFinds
     {
         object?[] convertedArgs = ConvertArgumentsToJavaScriptObjects(args);
 
-        Dictionary<string, object> parameters = new Dictionary<string, object>();
+        Dictionary<string, object?> parameters = new Dictionary<string, object?>();
         parameters.Add("script", script);
 
         if (convertedArgs != null && convertedArgs.Length > 0)
@@ -1024,7 +1012,7 @@ public class WebDriver : IWebDriver, ISearchContext, IJavaScriptExecutor, IFinds
             throw new ArgumentNullException(nameof(authenticatorId));
         }
 
-        Dictionary<string, object> parameters = new Dictionary<string, object>();
+        Dictionary<string, object?> parameters = new Dictionary<string, object?>();
         parameters.Add("authenticatorId", authenticatorId);
 
         this.Execute(DriverCommand.RemoveVirtualAuthenticator, parameters);
@@ -1051,7 +1039,7 @@ public class WebDriver : IWebDriver, ISearchContext, IJavaScriptExecutor, IFinds
 
         string authenticatorId = this.AuthenticatorId ?? throw new InvalidOperationException("Virtual Authenticator needs to be added before it can perform operations");
 
-        Dictionary<string, object> parameters = new Dictionary<string, object>(credential.ToDictionary());
+        Dictionary<string, object?> parameters = new Dictionary<string, object?>(credential.ToDictionary());
         parameters.Add("authenticatorId", authenticatorId);
 
         this.Execute(driverCommandToExecute: DriverCommand.AddCredential, parameters);
@@ -1066,7 +1054,7 @@ public class WebDriver : IWebDriver, ISearchContext, IJavaScriptExecutor, IFinds
     {
         string authenticatorId = this.AuthenticatorId ?? throw new InvalidOperationException("Virtual Authenticator needs to be added before it can perform operations");
 
-        Dictionary<string, object> parameters = new Dictionary<string, object>();
+        Dictionary<string, object?> parameters = new Dictionary<string, object?>();
         parameters.Add("authenticatorId", authenticatorId);
 
         Response getCredentialsResponse = this.Execute(driverCommandToExecute: DriverCommand.GetCredentials, parameters);
@@ -1113,7 +1101,7 @@ public class WebDriver : IWebDriver, ISearchContext, IJavaScriptExecutor, IFinds
 
         string authenticatorId = this.AuthenticatorId ?? throw new InvalidOperationException("Virtual Authenticator needs to be added before it can perform operations");
 
-        Dictionary<string, object> parameters = new Dictionary<string, object>();
+        Dictionary<string, object?> parameters = new Dictionary<string, object?>();
         parameters.Add("authenticatorId", authenticatorId);
         parameters.Add("credentialId", credentialId);
 
@@ -1128,7 +1116,7 @@ public class WebDriver : IWebDriver, ISearchContext, IJavaScriptExecutor, IFinds
     {
         string authenticatorId = this.AuthenticatorId ?? throw new InvalidOperationException("Virtual Authenticator needs to be added before it can perform operations");
 
-        Dictionary<string, object> parameters = new Dictionary<string, object>();
+        Dictionary<string, object?> parameters = new Dictionary<string, object?>();
         parameters.Add("authenticatorId", authenticatorId);
 
         this.Execute(driverCommandToExecute: DriverCommand.RemoveAllCredentials, parameters);
@@ -1142,7 +1130,7 @@ public class WebDriver : IWebDriver, ISearchContext, IJavaScriptExecutor, IFinds
     {
         string authenticatorId = this.AuthenticatorId ?? throw new InvalidOperationException("Virtual Authenticator needs to be added before it can perform operations");
 
-        Dictionary<string, object> parameters = new Dictionary<string, object>();
+        Dictionary<string, object?> parameters = new Dictionary<string, object?>();
         parameters.Add("authenticatorId", authenticatorId);
         parameters.Add("isUserVerified", verified);
 
