@@ -17,22 +17,21 @@
 // under the License.
 // </copyright>
 
-namespace OpenQA.Selenium.Safari
-{
-    // This is a simple wrapper class to create a SafariDriver that
-    // uses the technology preview implementation and has no parameters in the
-    // constructor.
-    public class DefaultSafariDriver : SafariDriver
-    {
-        // Required for dynamic setting with `EnvironmentManager.Instance.CreateDriverInstance(options)`
-        public DefaultSafariDriver(SafariOptions options)
-            : base(options)
-        {
-        }
+namespace OpenQA.Selenium.Safari;
 
-        public DefaultSafariDriver(SafariDriverService service, SafariOptions options)
-            : base(service, options)
-        {
-        }
+// This is a simple wrapper class to create a SafariDriver that
+// uses the technology preview implementation and has no parameters in the
+// constructor.
+public class DefaultSafariDriver : SafariDriver
+{
+    // Required for dynamic setting with `EnvironmentManager.Instance.CreateDriverInstance(options)`
+    public DefaultSafariDriver(SafariOptions options)
+        : base(options)
+    {
+    }
+
+    public DefaultSafariDriver(SafariDriverService service, SafariOptions options)
+        : base(service, options)
+    {
     }
 }
