@@ -37,8 +37,5 @@ public class StableChannelChromeDriver : ChromeDriver
     {
     }
 
-    public static ChromeOptions DefaultOptions
-    {
-        get { return new ChromeOptions(); }
-    }
+    public static ChromeOptions DefaultOptions => new ChromeOptions();
 }
