@@ -18,14 +18,14 @@
 // </copyright>
 
 using OpenQA.Selenium.Chrome;
-using System;
+using OpenQA.Selenium.Environment;
 
 namespace OpenQA.Selenium.Remote;
 
 public class StableChannelRemoteChromeDriver : RemoteWebDriver
 {
     public StableChannelRemoteChromeDriver()
-        : base(new Uri("http://127.0.0.1:6000/wd/hub/"), new ChromeOptions())
+        : base(RemoteSeleniumServer.ServerUri, new ChromeOptions())
     {
         this.FileDetector = new LocalFileDetector();
     }
