@@ -17,21 +17,11 @@
 // under the License.
 // </copyright>
 
-namespace OpenQA.Selenium.Environment
+namespace OpenQA.Selenium.Environment;
+
+public class DriverStartingEventArgs(DriverService service, DriverOptions options)
 {
-    public class DriverStartingEventArgs
-    {
-        DriverService service;
-        DriverOptions options;
+    public DriverService Service { get; } = service;
 
-        public DriverStartingEventArgs(DriverService service, DriverOptions options)
-        {
-            this.Service = service;
-            this.Options = options;
-        }
-
-        public DriverService Service { get => service; set => service = value; }
-
-        public DriverOptions Options { get => options; set => options = value; }
-    }
+    public DriverOptions Options { get; } = options;
 }
