@@ -25,9 +25,9 @@ namespace OpenQA.Selenium.Environment;
 public class InlinePage
 {
     private string title = string.Empty;
-    private List<string> scripts = new List<string>();
-    private List<string> styles = new List<string>();
-    private List<string> bodyParts = new List<string>();
+    private readonly List<string> scripts = new List<string>();
+    private readonly List<string> styles = new List<string>();
+    private readonly List<string> bodyParts = new List<string>();
     private string onLoad;
     private string onBeforeUnload;
 
