@@ -18,7 +18,7 @@
 // </copyright>
 
 using OpenQA.Selenium.Chrome;
-using System;
+using OpenQA.Selenium.Environment;
 
 namespace OpenQA.Selenium.Remote;
 
@@ -27,7 +27,7 @@ namespace OpenQA.Selenium.Remote;
 public class ChromeRemoteWebDriver : RemoteWebDriver
 {
     public ChromeRemoteWebDriver()
-        : base(new Uri("http://127.0.0.1:6000/wd/hub/"), new ChromeOptions())
+        : base(RemoteSeleniumServer.ServerUri, new ChromeOptions())
     {
     }
 }
