@@ -23,7 +23,6 @@ import java.util.List;
 import java.util.Map;
 import java.util.Objects;
 import java.util.regex.Pattern;
-import org.jspecify.annotations.NullMarked;
 import org.jspecify.annotations.Nullable;
 import org.openqa.selenium.internal.Require;
 
@@ -42,7 +41,6 @@ import org.openqa.selenium.internal.Require;
  * }
  * </code></pre>
  */
-@NullMarked
 public abstract class By {
   /**
    * @param id The value of the "id" attribute to search for.
