@@ -17,6 +17,8 @@
 
 package org.openqa.selenium;
 
+import org.jspecify.annotations.Nullable;
+
 public enum UnexpectedAlertBehaviour {
   ACCEPT("accept"),
   DISMISS("dismiss"),
@@ -35,7 +37,7 @@ public enum UnexpectedAlertBehaviour {
     return String.valueOf(text);
   }
 
-  public static UnexpectedAlertBehaviour fromString(String text) {
+  public static @Nullable UnexpectedAlertBehaviour fromString(@Nullable String text) {
     if (text != null) {
       for (UnexpectedAlertBehaviour b : UnexpectedAlertBehaviour.values()) {
         if (text.equalsIgnoreCase(b.text)) {
