@@ -19,6 +19,6 @@ package org.openqa.selenium.bidi.webextension;
 
 import java.util.Map;
 
-public abstract class ExtensionData {
-  public abstract Map<String, Object> toMap();
+public interface ExtensionData {
+  Map<String, Object> toMap();
 }
