@@ -19,7 +19,7 @@ package org.openqa.selenium.bidi.webextension;
 
 import java.util.Map;
 
-public class ExtensionPath extends ExtensionData {
+public class ExtensionPath implements ExtensionData {
   private final String path;
 
   public ExtensionPath(String path) {
@@ -28,7 +28,6 @@ public class ExtensionPath extends ExtensionData {
 
   @Override
   public Map<String, Object> toMap() {
-    String type = "path";
-    return Map.of("extensionData", Map.of("type", type, "path", path));
+    return Map.of("extensionData", Map.of("type", "path", "path", path));
   }
 }
