@@ -17,18 +17,17 @@
 
 package org.openqa.selenium.grid.commands;
 
-import com.google.common.collect.ImmutableMap;
+import java.util.Map;
 import org.openqa.selenium.grid.config.MapConfig;
 
 class DefaultStandaloneConfig extends MapConfig {
 
   DefaultStandaloneConfig() {
     super(
-        ImmutableMap.of(
-            "events",
-                ImmutableMap.of("implementation", "org.openqa.selenium.events.local.GuavaEventBus"),
+        Map.of(
+            "events", Map.of("implementation", "org.openqa.selenium.events.local.GuavaEventBus"),
             "sessions",
-                ImmutableMap.of(
+                Map.of(
                     "implementation",
                     "org.openqa.selenium.grid.sessionmap.local.LocalSessionMap")));
   }
