@@ -28,13 +28,12 @@ import static org.openqa.selenium.remote.http.HttpMethod.GET;
 import static org.openqa.selenium.remote.http.Route.get;
 
 import com.google.auto.service.AutoService;
-import com.google.common.collect.ImmutableMap;
-import com.google.common.collect.ImmutableSet;
 import com.google.common.net.MediaType;
 import java.io.Closeable;
 import java.io.IOException;
 import java.io.UncheckedIOException;
 import java.util.Collections;
+import java.util.Map;
 import java.util.Set;
 import java.util.logging.Level;
 import java.util.logging.Logger;
@@ -69,7 +68,7 @@ public class DistributorServer extends TemplateGridServerCommand {
 
   @Override
   public Set<Role> getConfigurableRoles() {
-    return ImmutableSet.of(
+    return Set.of(
         DISTRIBUTOR_ROLE, EVENT_BUS_ROLE, HTTPD_ROLE, SESSION_MAP_ROLE, SESSION_QUEUE_ROLE);
   }
 
@@ -113,9 +112,9 @@ public class DistributorServer extends TemplateGridServerCommand {
                             new HttpResponse()
                                 .setContent(
                                     Contents.asJson(
-                                        ImmutableMap.of(
+                                        Map.of(
                                             "value",
-                                            ImmutableMap.of(
+                                            Map.of(
                                                 "ready",
                                                 true,
                                                 "message",
