@@ -29,6 +29,7 @@ import static org.openqa.selenium.remote.tracing.Tags.EXCEPTION;
 
 import com.google.common.annotations.VisibleForTesting;
 import java.io.Closeable;
+import java.io.IOException;
 import java.io.UncheckedIOException;
 import java.net.URI;
 import java.time.Duration;
@@ -38,7 +39,10 @@ import java.util.Optional;
 import java.util.Set;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
+import java.util.concurrent.LinkedBlockingQueue;
+import java.util.concurrent.RejectedExecutionException;
 import java.util.concurrent.ScheduledExecutorService;
+import java.util.concurrent.ThreadPoolExecutor;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.locks.Lock;
 import java.util.concurrent.locks.ReadWriteLock;
@@ -182,7 +186,6 @@ public class LocalDistributor extends Distributor implements Closeable {
         new LocalNodeRegistry(
             tracer,
             bus,
-            newSessionThreadPoolSize,
             this.clientFactory,
             this.registrationSecret,
             this.healthcheckInterval,
@@ -191,14 +194,19 @@ public class LocalDistributor extends Distributor implements Closeable {
             this.purgeDeadNodesService);
 
     sessionCreatorExecutor =
-        Executors.newFixedThreadPool(
+        new ThreadPoolExecutor(
             newSessionThreadPoolSize,
+            newSessionThreadPoolSize,
+            0L,
+            TimeUnit.MILLISECONDS,
+            new LinkedBlockingQueue<>(),
             r -> {
               Thread thread = new Thread(r);
               thread.setName("Local Distributor - Session Creation");
               thread.setDaemon(true);
               return thread;
-            });
+            },
+            new ThreadPoolExecutor.AbortPolicy());
 
     NewSessionRunnable newSessionRunnable = new NewSessionRunnable();
 
@@ -515,10 +523,15 @@ public class LocalDistributor extends Distributor implements Closeable {
   @Override
   public void close() {
     LOG.info("Shutting down Distributor executor service");
-    shutdownGracefully("Local Distributor - Purge Dead Nodes", purgeDeadNodesService);
-    shutdownGracefully("Local Distributor - Node Health Check", nodeHealthCheckService);
     shutdownGracefully("Local Distributor - New Session Queue", newSessionService);
     shutdownGracefully("Local Distributor - Session Creation", sessionCreatorExecutor);
+    shutdownGracefully("Local Distributor - Node Health Check", nodeHealthCheckService);
+    shutdownGracefully("Local Distributor - Purge Dead Nodes", purgeDeadNodesService);
+    try {
+      nodeRegistry.close();
+    } catch (IOException e) {
+      LOG.log(Level.WARNING, "Unable to close node registry cleanly", e);
+    }
   }
 
   private class NewSessionRunnable implements Runnable {
@@ -554,7 +567,16 @@ public class LocalDistributor extends Distributor implements Closeable {
         if (!stereotypes.isEmpty()) {
           List<SessionRequest> matchingRequests = sessionQueue.getNextAvailable(stereotypes);
           matchingRequests.forEach(
-              req -> sessionCreatorExecutor.execute(() -> handleNewSessionRequest(req)));
+              req -> {
+                try {
+                  sessionCreatorExecutor.execute(() -> handleNewSessionRequest(req));
+                } catch (RejectedExecutionException e) {
+                  LOG.log(
+                      getDebugLogLevel(),
+                      "Dropping session creation task while shutting down distributor",
+                      e);
+                }
+              });
         }
       }
 
