@@ -40,6 +40,7 @@ import java.util.Map;
 import java.util.Objects;
 import java.util.Optional;
 import java.util.Set;
+import java.util.concurrent.RejectedExecutionException;
 import org.openqa.selenium.Capabilities;
 import org.openqa.selenium.NoSuchSessionException;
 import org.openqa.selenium.RetrySessionRequestException;
@@ -73,7 +74,11 @@ import org.openqa.selenium.remote.tracing.Tracer;
 public class RemoteNode extends Node implements Closeable {
 
   public static final Json JSON = new Json();
-  private final HttpHandler client;
+  // Health checks only need /status to respond quickly; no need for the full session timeout.
+  static final Duration HEALTH_CHECK_CONNECTION_TIMEOUT = Duration.ofSeconds(5);
+  static final Duration HEALTH_CHECK_READ_TIMEOUT = Duration.ofSeconds(30);
+  private final HttpClient client;
+  private final HttpClient healthCheckClient;
   private final URI externalUri;
   private final Set<Capabilities> capabilities;
   private final HealthCheck healthCheck;
@@ -93,7 +98,14 @@ public class RemoteNode extends Node implements Closeable {
 
     ClientConfig clientConfig =
         defaultConfig().readTimeout(this.getSessionTimeout()).baseUrl(fromUri(externalUri));
-    this.client = Require.nonNull("HTTP client factory", clientFactory).createClient(clientConfig);
+    HttpClient.Factory factory = Require.nonNull("HTTP client factory", clientFactory);
+    this.client = factory.createClient(clientConfig);
+
+    this.healthCheckClient =
+        factory.createClient(
+            clientConfig
+                .connectionTimeout(HEALTH_CHECK_CONNECTION_TIMEOUT)
+                .readTimeout(HEALTH_CHECK_READ_TIMEOUT));
 
     this.healthCheck = new RemoteCheck();
 
@@ -140,6 +152,22 @@ public class RemoteNode extends Node implements Closeable {
       // timeout, the SessionRequest is marked as canceled and the session is either not added to
       // the queue or disposed as soon as the node started it.
       return Either.left(new RetrySessionRequestException("Timeout while starting the session", e));
+    } catch (UncheckedIOException e) {
+      // Walk the cause chain: if a RejectedExecutionException is present the JDK HTTP client's
+      // internal executor received a shutdown signal while this request was in flight (the node
+      // is restarting or draining). Signal the distributor to retry on a different node.
+      // Other UncheckedIOExceptions (connection refused, reset, etc.) are re-thrown unchanged.
+      for (Throwable cause = e; cause != null; cause = cause.getCause()) {
+        if (cause instanceof RejectedExecutionException) {
+          return Either.left(
+              new RetrySessionRequestException(
+                  "Node "
+                      + externalUri
+                      + " rejected the execution (possibly restarting or shutting down)",
+                  e));
+        }
+      }
+      throw e;
     }
 
     Optional<Map<String, Object>> maybeResponse =
@@ -233,6 +261,11 @@ public class RemoteNode extends Node implements Closeable {
     return client.execute(req);
   }
 
+  @Override
+  public HttpResponse fireSessionEvent(HttpRequest req, SessionId id) {
+    return client.execute(req);
+  }
+
   @Override
   public void stop(SessionId id) throws NoSuchSessionException {
     Require.nonNull("Session ID", id);
@@ -246,10 +279,14 @@ public class RemoteNode extends Node implements Closeable {
 
   @Override
   public NodeStatus getStatus() {
+    return getStatus(client);
+  }
+
+  private NodeStatus getStatus(HttpHandler handler) {
     HttpRequest req = new HttpRequest(GET, "/status");
     HttpTracing.inject(tracer, tracer.getCurrentContext(), req);
 
-    HttpResponse res = client.execute(req);
+    HttpResponse res = handler.execute(req);
 
     try (Reader reader = reader(res);
         JsonInput in = JSON.newInput(reader)) {
@@ -307,14 +344,15 @@ public class RemoteNode extends Node implements Closeable {
 
   @Override
   public void close() {
-    ((HttpClient) (this.client)).close();
+    this.client.close();
+    this.healthCheckClient.close();
   }
 
   private class RemoteCheck implements HealthCheck {
     @Override
     public Result check() {
       try {
-        NodeStatus status = getStatus();
+        NodeStatus status = getStatus(healthCheckClient);
 
         if (status.getNodeId() != null && !Objects.equals(getId(), status.getNodeId())) {
           // ensure the original RemoteNode stays DOWN when it has been restarted and registered
