@@ -20,7 +20,6 @@ package org.openqa.selenium.remote;
 import java.util.Map;
 import org.jspecify.annotations.NullMarked;
 import org.jspecify.annotations.Nullable;
-import org.openqa.selenium.WebDriver;
 import org.openqa.selenium.WrapsDriver;
 import org.openqa.selenium.internal.Require;
 
@@ -46,7 +45,7 @@ public class RemoteExecuteMethod implements ExecuteMethod, WrapsDriver {
   }
 
   @Override
-  public WebDriver getWrappedDriver() {
+  public RemoteWebDriver getWrappedDriver() {
     return this.driver;
   }
 }
