@@ -46,6 +46,7 @@ import java.util.logging.Level;
 import java.util.logging.Logger;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
+import org.jspecify.annotations.NonNull;
 import org.openqa.selenium.AcceptedW3CCapabilityKeys;
 import org.openqa.selenium.Alert;
 import org.openqa.selenium.Beta;
@@ -93,6 +94,7 @@ import org.openqa.selenium.remote.http.ClientConfig;
 import org.openqa.selenium.remote.http.ConnectionFailedException;
 import org.openqa.selenium.remote.http.Contents;
 import org.openqa.selenium.remote.http.HttpClient;
+import org.openqa.selenium.remote.http.jdk.ConnectionException;
 import org.openqa.selenium.remote.service.DriverCommandExecutor;
 import org.openqa.selenium.remote.tracing.TracedHttpClient;
 import org.openqa.selenium.remote.tracing.Tracer;
@@ -356,6 +358,7 @@ public class RemoteWebDriver
     this.executor = executor;
   }
 
+  @NonNull
   @Override
   public Capabilities getCapabilities() {
     if (capabilities == null) {
@@ -628,6 +631,11 @@ public class RemoteWebDriver
         }
       } else if (e instanceof WebDriverException) {
         toThrow = (WebDriverException) e;
+      } else if (e instanceof ConnectionException) {
+        ConnectionException cause = (ConnectionException) e;
+        toThrow =
+            new UnreachableBrowserException(
+                "Error communicating with the remote browser at " + cause.uri(), cause);
       } else {
         toThrow =
             new UnreachableBrowserException(
@@ -802,6 +810,45 @@ public class RemoteWebDriver
     execute(DriverCommand.DELETE_DOWNLOADABLE_FILES);
   }
 
+  /**
+   * Fires a custom session event to the remote server event bus. This allows test code to trigger
+   * server-side utilities that subscribe to the event bus.
+   *
+   * <p>Example usage:
+   *
+   * <pre>{@code
+   * // Simple event
+   * driver.fireSessionEvent("test:started");
+   *
+   * // Event with payload
+   * driver.fireSessionEvent("test:failed", Map.of(
+   *     "testName", "LoginTest",
+   *     "error", "Element not found"
+   * ));
+   * }</pre>
+   *
+   * @param eventType the type of event (e.g., "test:failed", "log:collect", "marker:add")
+   * @param payload optional data to include with the event (maybe null or empty)
+   * @return the response data from the server
+   * @throws WebDriverException if the event cannot be fired
+   */
+  public Map<String, Object> fireSessionEvent(String eventType, Map<String, Object> payload) {
+    Response response = execute(DriverCommand.FIRE_SESSION_EVENT(eventType, payload));
+    return (Map<String, Object>) response.getValue();
+  }
+
+  /**
+   * Fires a custom session event to the remote server event bus without a payload.
+   *
+   * @param eventType the type of event (e.g., "test:started", "log:collect")
+   * @return the response data from the server
+   * @throws WebDriverException if the event cannot be fired
+   * @see #fireSessionEvent(String, Map)
+   */
+  public Map<String, Object> fireSessionEvent(String eventType) {
+    return fireSessionEvent(eventType, null);
+  }
+
   @Override
   public void setDelayEnabled(boolean enabled) {
     execute(DriverCommand.SET_DELAY_ENABLED(enabled));
