@@ -23,6 +23,7 @@ import static org.assertj.core.api.Assertions.assertThatExceptionOfType;
 import static org.openqa.selenium.WaitingConditions.newWindowIsOpened;
 import static org.openqa.selenium.support.ui.ExpectedConditions.alertIsPresent;
 import static org.openqa.selenium.support.ui.ExpectedConditions.presenceOfElementLocated;
+import static org.openqa.selenium.support.ui.ExpectedConditions.titleIs;
 import static org.openqa.selenium.testing.drivers.Browser.CHROME;
 import static org.openqa.selenium.testing.drivers.Browser.EDGE;
 import static org.openqa.selenium.testing.drivers.Browser.FIREFOX;
@@ -467,7 +468,9 @@ class AlertsTest extends JupiterTestBase {
             new Page()
                 .withTitle("Testing Alerts")
                 .withBody(
-                    "<form id='theForm' action='javascript:alert(\"Tasty cheese\");'>",
+                    "<form id='theForm'"
+                        + "    action='/click_tests/submitted_page.html' "
+                        + "    onsubmit='return alert(\"Tasty cheese\");'>",
                     "<input id='unused' type='submit' value='Submit'>",
                     "</form>")));
 
@@ -477,6 +480,8 @@ class AlertsTest extends JupiterTestBase {
     alert.accept();
 
     assertThat(value).isEqualTo("Tasty cheese");
-    assertThat(driver.getTitle()).isEqualTo("Testing Alerts");
+
+    wait.until(titleIs("Submitted Successfully!"));
+    assertThat(driver.getCurrentUrl()).contains("submitted_page.html");
   }
 }
