@@ -20,16 +20,21 @@ package org.openqa.selenium.bidi.browsingcontext;
 import static java.nio.charset.StandardCharsets.US_ASCII;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
+import static org.assertj.core.data.Offset.offset;
 import static org.openqa.selenium.support.ui.ExpectedConditions.alertIsPresent;
 import static org.openqa.selenium.support.ui.ExpectedConditions.titleIs;
 import static org.openqa.selenium.support.ui.ExpectedConditions.visibilityOfElementLocated;
 
+import java.awt.image.BufferedImage;
+import java.io.ByteArrayInputStream;
+import java.io.IOException;
 import java.util.Base64;
 import java.util.List;
+import javax.imageio.ImageIO;
+import org.assertj.core.data.Offset;
 import org.junit.jupiter.api.Test;
 import org.openqa.selenium.By;
 import org.openqa.selenium.Dimension;
-import org.openqa.selenium.JavascriptExecutor;
 import org.openqa.selenium.Rectangle;
 import org.openqa.selenium.WebElement;
 import org.openqa.selenium.WindowType;
@@ -397,14 +402,29 @@ class BrowsingContextTest extends JupiterTestBase {
   // Meanwhile, trusting the browsers to do the right thing.
   @Test
   @NeedsFreshDriver
-  void canCaptureScreenshot() {
+  void canCaptureScreenshot() throws IOException {
     BrowsingContext browsingContext = new BrowsingContext(driver, driver.getWindowHandle());
 
     driver.get(pages.simpleTestPage);
 
     String screenshot = browsingContext.captureScreenshot();
 
-    assertThat(screenshot).isNotEmpty();
+    verifyScreenshot(screenshot);
+  }
+
+  private void verifyScreenshot(String screenshotBase64) throws IOException {
+    byte[] screenshotBytes = Base64.getDecoder().decode(screenshotBase64);
+    BufferedImage screenshot = ImageIO.read(new ByteArrayInputStream(screenshotBytes));
+    Dimension expectedSize = getViewportSize();
+
+    assertLength(screenshot.getWidth(), expectedSize.getWidth());
+    assertLength(screenshot.getHeight(), expectedSize.getHeight());
+  }
+
+  private void assertLength(int length, int expected) {
+    int expectedLength = (int) (expected * getDevicePixelRatio());
+    Offset<Integer> tolerance = offset(20);
+    assertThat(length).isCloseTo(expectedLength, tolerance);
   }
 
   @Test
@@ -574,20 +594,16 @@ class BrowsingContextTest extends JupiterTestBase {
                 "<p id=\"result\"></p>"));
   }
 
-  private <T> T executeScript(String js) {
-    return (T) ((JavascriptExecutor) driver).executeScript(js);
-  }
-
   private boolean isDocumentFocused() {
-    return executeScript("return document.hasFocus();");
+    return executeJavaScript("return document.hasFocus();");
   }
 
   private Dimension getViewportSize() {
-    List<Number> dimensions = executeScript("return [window.innerWidth, window.innerHeight];");
+    List<Number> dimensions = executeJavaScript("return [window.innerWidth, window.innerHeight];");
     return new Dimension(dimensions.get(0).intValue(), dimensions.get(1).intValue());
   }
 
   private double getDevicePixelRatio() {
-    return ((Number) executeScript("return window.devicePixelRatio")).doubleValue();
+    return ((Number) executeJavaScript("return window.devicePixelRatio")).doubleValue();
   }
 }
