@@ -19,7 +19,6 @@ package org.openqa.selenium.bidi.log;
 
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatExceptionOfType;
-import static org.assertj.core.api.Assertions.fail;
 
 import java.util.HashSet;
 import java.util.Set;
@@ -54,10 +53,10 @@ class LogInspectorTest extends JupiterTestBase {
 
       ConsoleLogEntry logEntry = future.get(5, TimeUnit.SECONDS);
       Source source = logEntry.getSource();
-      assertThat(source.getBrowsingContext().isPresent()).isTrue();
+      assertThat(source.getBrowsingContext()).isPresent();
       assertThat(source.getRealm()).isNotNull();
       assertThat(logEntry.getText()).isEqualTo("Hello, world!");
-      assertThat(logEntry.getArgs().size()).isEqualTo(1);
+      assertThat(logEntry.getArgs()).hasSize(1);
       assertThat(logEntry.getArgs().get(0).getType()).isEqualTo("string");
       assertThat(logEntry.getType()).isEqualTo("console");
       assertThat(logEntry.getLevel()).isEqualTo(LogLevel.INFO);
@@ -79,25 +78,25 @@ class LogInspectorTest extends JupiterTestBase {
       ConsoleLogEntry logEntry = future.get(5, TimeUnit.SECONDS);
 
       assertThat(logEntry.getText()).isEqualTo("Hello, world!");
-      assertThat(logEntry.getArgs().size()).isEqualTo(1);
+      assertThat(logEntry.getArgs()).hasSize(1);
       assertThat(logEntry.getType()).isEqualTo("console");
       assertThat(logEntry.getLevel()).isEqualTo(LogLevel.INFO);
       assertThat(logEntry.getMethod()).isEqualTo("log");
 
-      CompletableFuture<ConsoleLogEntry> errorLogfuture = new CompletableFuture<>();
+      CompletableFuture<ConsoleLogEntry> errorLogFuture = new CompletableFuture<>();
 
-      logInspector.onConsoleEntry(errorLogfuture::complete, FilterBy.logLevel(LogLevel.ERROR));
+      logInspector.onConsoleEntry(errorLogFuture::complete, FilterBy.logLevel(LogLevel.ERROR));
       driver.findElement(By.id("consoleError")).click();
 
-      ConsoleLogEntry errorLogEntry = errorLogfuture.get(5, TimeUnit.SECONDS);
+      ConsoleLogEntry errorLogEntry = errorLogFuture.get(5, TimeUnit.SECONDS);
 
       assertThat(errorLogEntry.getText()).isEqualTo("I am console error");
-      assertThat(errorLogEntry.getArgs().size()).isEqualTo(1);
+      assertThat(errorLogEntry.getArgs()).hasSize(1);
       assertThat(errorLogEntry.getType()).isEqualTo("console");
       assertThat(errorLogEntry.getLevel()).isEqualTo(LogLevel.ERROR);
       assertThat(errorLogEntry.getMethod()).isEqualTo("error");
       assertThat(errorLogEntry.getStackTrace()).isNotNull();
-      assertThat(errorLogEntry.getStackTrace().getCallFrames().size()).isEqualTo(2);
+      assertThat(errorLogEntry.getStackTrace().getCallFrames()).hasSize(2);
     }
   }
 
@@ -116,7 +115,7 @@ class LogInspectorTest extends JupiterTestBase {
       JavascriptLogEntry logEntry = future.get(5, TimeUnit.SECONDS);
 
       Source source = logEntry.getSource();
-      assertThat(source.getBrowsingContext().isPresent()).isTrue();
+      assertThat(source.getBrowsingContext()).isPresent();
       assertThat(source.getRealm()).isNotNull();
 
       assertThat(logEntry.getText()).isEqualTo("Error: Not working");
@@ -127,7 +126,7 @@ class LogInspectorTest extends JupiterTestBase {
 
   @Test
   @NeedsFreshDriver
-  void canFilterJavascriptLogs() throws ExecutionException, InterruptedException {
+  void canFilterJavascriptLogs() throws ExecutionException, InterruptedException, TimeoutException {
     try (LogInspector logInspector = new LogInspector(driver)) {
       CompletableFuture<JavascriptLogEntry> future = new CompletableFuture<>();
       logInspector.onJavaScriptLog(future::complete, FilterBy.logLevel(LogLevel.ERROR));
@@ -136,12 +135,7 @@ class LogInspectorTest extends JupiterTestBase {
       driver.get(page);
       driver.findElement(By.id("jsException")).click();
 
-      JavascriptLogEntry logEntry = null;
-      try {
-        logEntry = future.get(5, TimeUnit.SECONDS);
-      } catch (TimeoutException e) {
-        fail("Time out exception" + e.getMessage());
-      }
+      JavascriptLogEntry logEntry = future.get(5, TimeUnit.SECONDS);
 
       assertThat(logEntry.getText()).isEqualTo("Error: Not working");
       assertThat(logEntry.getType()).isEqualTo("javascript");
@@ -198,7 +192,7 @@ class LogInspectorTest extends JupiterTestBase {
 
   @Test
   @NeedsFreshDriver
-  void canFilterLogs() throws ExecutionException, InterruptedException {
+  void canFilterLogs() throws ExecutionException, InterruptedException, TimeoutException {
     try (LogInspector logInspector = new LogInspector(driver)) {
       CompletableFuture<LogEntry> future = new CompletableFuture<>();
       logInspector.onLog(future::complete, FilterBy.logLevel(LogLevel.INFO));
@@ -207,18 +201,13 @@ class LogInspectorTest extends JupiterTestBase {
       driver.get(page);
       driver.findElement(By.id("consoleLog")).click();
 
-      LogEntry logEntry = null;
-      try {
-        logEntry = future.get(5, TimeUnit.SECONDS);
-      } catch (TimeoutException e) {
-        fail("Time out exception" + e.getMessage());
-      }
+      LogEntry logEntry = future.get(5, TimeUnit.SECONDS);
 
-      assertThat(logEntry.getConsoleLogEntry().isPresent()).isTrue();
+      assertThat(logEntry.getConsoleLogEntry()).isPresent();
 
       ConsoleLogEntry consoleLogEntry = logEntry.getConsoleLogEntry().get();
       assertThat(consoleLogEntry.getText()).isEqualTo("Hello, world!");
-      assertThat(consoleLogEntry.getArgs().size()).isEqualTo(1);
+      assertThat(consoleLogEntry.getArgs()).hasSize(1);
       assertThat(consoleLogEntry.getType()).isEqualTo("console");
       assertThat(consoleLogEntry.getLevel()).isEqualTo(LogLevel.INFO);
       assertThat(consoleLogEntry.getMethod()).isEqualTo("log");
@@ -243,7 +232,7 @@ class LogInspectorTest extends JupiterTestBase {
       ConsoleLogEntry logEntry = future.get(5, TimeUnit.SECONDS);
 
       assertThat(logEntry.getText()).isEqualTo("Hello, world!");
-      assertThat(logEntry.getArgs().size()).isEqualTo(1);
+      assertThat(logEntry.getArgs()).hasSize(1);
       assertThat(logEntry.getType()).isEqualTo("console");
       assertThat(logEntry.getLevel()).isEqualTo(LogLevel.INFO);
       assertThat(logEntry.getMethod()).isEqualTo("log");
@@ -299,8 +288,7 @@ class LogInspectorTest extends JupiterTestBase {
   @Disabled("Until browsers support subscribing to multiple contexts.")
   @Test
   @NeedsFreshDriver
-  void canListenToConsoleLogForMultipleBrowsingContexts()
-      throws ExecutionException, InterruptedException, TimeoutException {
+  void canListenToConsoleLogForMultipleBrowsingContexts() throws InterruptedException {
     page = appServer.whereIs("/bidi/logEntryAdded.html");
     String firstBrowsingContextId = driver.getWindowHandle();
     String secondBrowsingContextId = driver.switchTo().newWindow(WindowType.TAB).getWindowHandle();
