@@ -17,20 +17,18 @@
 
 package org.openqa.selenium.grid.node.config;
 
-import static java.util.Collections.emptyMap;
+import static java.net.URI.create;
 import static java.util.Collections.emptySet;
 import static java.util.Collections.singletonMap;
 import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
 import static org.assertj.core.api.InstanceOfAssertFactories.LIST;
 import static org.assertj.core.api.InstanceOfAssertFactories.MAP;
-import static org.junit.jupiter.api.Assertions.fail;
 import static org.junit.jupiter.api.Assumptions.assumeFalse;
 import static org.junit.jupiter.api.Assumptions.assumeTrue;
 import static org.openqa.selenium.remote.CapabilityType.ENABLE_DOWNLOADS;
 
-import com.google.common.collect.ImmutableMap;
 import java.io.StringReader;
-import java.net.URI;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
@@ -45,7 +43,6 @@ import org.openqa.selenium.ImmutableCapabilities;
 import org.openqa.selenium.Platform;
 import org.openqa.selenium.SessionNotCreatedException;
 import org.openqa.selenium.WebDriverException;
-import org.openqa.selenium.WebDriverInfo;
 import org.openqa.selenium.chrome.ChromeDriverInfo;
 import org.openqa.selenium.chrome.ChromeOptions;
 import org.openqa.selenium.edge.EdgeDriverInfo;
@@ -64,6 +61,7 @@ import org.openqa.selenium.ie.InternetExplorerDriverInfo;
 import org.openqa.selenium.internal.Either;
 import org.openqa.selenium.json.Json;
 import org.openqa.selenium.net.NetworkUtils;
+import org.openqa.selenium.remote.WebDriverInfo;
 import org.openqa.selenium.safari.SafariDriverInfo;
 
 @SuppressWarnings("DuplicatedCode")
@@ -133,9 +131,9 @@ class NodeOptionsTest {
     assumeTrue(driver.isPresent(), customMsg + " needs to be available");
     Config config =
         new MapConfig(
-            singletonMap(
+            Map.of(
                 "node",
-                ImmutableMap.of(
+                Map.of(
                     "detect-drivers",
                     "true",
                     "selenium-manager",
@@ -298,23 +296,22 @@ class NodeOptionsTest {
   void shouldThrowConfigExceptionIfDetectDriversIsFalseAndSpecificDriverIsAdded() {
     Config config =
         new MapConfig(
-            singletonMap(
+            Map.of(
                 "node",
-                ImmutableMap.of(
+                Map.of(
                     "detect-drivers", "false",
                     "driver-implementation", "[chrome]")));
     List<Capabilities> reported = new ArrayList<>();
-    try {
-      new NodeOptions(config)
-          .getSessionFactories(
-              caps -> {
-                reported.add(caps);
-                return Collections.singleton(HelperFactory.create(config, caps));
-              });
-      fail("Should have not executed 'getSessionFactories' successfully");
-    } catch (ConfigException e) {
-      // Fall through
-    }
+    assertThatThrownBy(
+            () ->
+                new NodeOptions(config)
+                    .getSessionFactories(
+                        caps -> {
+                          reported.add(caps);
+                          return Collections.singleton(HelperFactory.create(config, caps));
+                        }))
+        .isInstanceOf(ConfigException.class)
+        .hasMessage("Specific drivers cannot be added if 'detect-drivers' is set to false");
 
     assertThat(reported).isEmpty();
   }
@@ -325,7 +322,7 @@ class NodeOptionsTest {
         new ChromeDriverInfo().isPresent() || new GeckoDriverInfo().isPresent(),
         "A driver needs to be available");
 
-    Config config = new MapConfig(emptyMap());
+    Config config = new MapConfig();
 
     List<Capabilities> reported = new ArrayList<>();
     new NodeOptions(config)
@@ -549,19 +546,19 @@ class NodeOptionsTest {
     Config config = new TomlConfig(new StringReader(String.join("\n", rawConfig)));
 
     List<Capabilities> reported = new ArrayList<>();
-    try {
-      new NodeOptions(config)
-          .getSessionFactories(
-              caps -> {
-                reported.add(caps);
-                return Collections.singleton(HelperFactory.create(config, caps));
-              });
-      fail(
-          "Should have not executed 'getSessionFactories' successfully because driver config "
-              + "needs the stereotype field");
-    } catch (ConfigException e) {
-      // Fall through
-    }
+    assertThatThrownBy(
+            () ->
+                new NodeOptions(config)
+                    .getSessionFactories(
+                        caps -> {
+                          reported.add(caps);
+                          return Collections.singleton(HelperFactory.create(config, caps));
+                        }))
+        .as("driver config needs the stereotype field")
+        .isInstanceOf(ConfigException.class)
+        .hasMessage(
+            "Found config with no 'stereotype' setting! {display-name=Chrome Beta, max-sessions=2,"
+                + " cheese=paipa}");
 
     assertThat(reported).isEmpty();
   }
@@ -599,7 +596,7 @@ class NodeOptionsTest {
     int maxRecommendedSessions = Runtime.getRuntime().availableProcessors();
     int overriddenMaxSessions = maxRecommendedSessions + 10;
     Config config =
-        new MapConfig(singletonMap("node", ImmutableMap.of("max-sessions", overriddenMaxSessions)));
+        new MapConfig(singletonMap("node", Map.of("max-sessions", overriddenMaxSessions)));
     List<Capabilities> reported = new ArrayList<>();
     try {
       new NodeOptions(config)
@@ -625,10 +622,9 @@ class NodeOptionsTest {
     int overriddenMaxSessions = maxRecommendedSessions + 10;
     Config config =
         new MapConfig(
-            singletonMap(
+            Map.of(
                 "node",
-                ImmutableMap.of(
-                    "max-sessions", overriddenMaxSessions, "override-max-sessions", true)));
+                Map.of("max-sessions", overriddenMaxSessions, "override-max-sessions", true)));
     List<Capabilities> reported = new ArrayList<>();
     try {
       new NodeOptions(config)
@@ -656,8 +652,7 @@ class NodeOptionsTest {
     Config config = new TomlConfig(new StringReader(String.join("\n", rawConfig)));
 
     NodeOptions nodeOptions = new NodeOptions(config);
-    assertThat(nodeOptions.getPublicGridUri())
-        .isEqualTo(Optional.of(URI.create("http://cheese.com:4444")));
+    assertThat(nodeOptions.getPublicGridUri()).contains(create("http://cheese.com:4444"));
   }
 
   @Test
@@ -670,8 +665,7 @@ class NodeOptionsTest {
     String nonLoopbackAddress = new NetworkUtils().getNonLoopbackAddressOfThisMachine();
     String nonLoopbackAddressUrl = String.format("http://%s:4444", nonLoopbackAddress);
     NodeOptions nodeOptions = new NodeOptions(config);
-    assertThat(nodeOptions.getPublicGridUri())
-        .isEqualTo(Optional.of(URI.create(nonLoopbackAddressUrl)));
+    assertThat(nodeOptions.getPublicGridUri()).contains(create(nonLoopbackAddressUrl));
   }
 
   @Test
@@ -776,8 +770,7 @@ class NodeOptionsTest {
     Config config =
         new MapConfig(
             singletonMap(
-                "node",
-                ImmutableMap.of("detect-drivers", "false", "delete-session-on-ui", "true")));
+                "node", Map.of("detect-drivers", "false", "delete-session-on-ui", "true")));
     NodeOptions nodeOptions = new NodeOptions(config);
     assertThat(nodeOptions.isSessionDeletedOnUi()).isTrue();
   }
@@ -787,8 +780,7 @@ class NodeOptionsTest {
     Config config =
         new MapConfig(
             singletonMap(
-                "node",
-                ImmutableMap.of("detect-drivers", "false", "delete-session-on-ui", "false")));
+                "node", Map.of("detect-drivers", "false", "delete-session-on-ui", "false")));
     NodeOptions nodeOptions = new NodeOptions(config);
     assertThat(nodeOptions.isSessionDeletedOnUi()).isFalse();
   }
@@ -801,8 +793,7 @@ class NodeOptionsTest {
 
     Config config =
         new MapConfig(
-            singletonMap(
-                "node", ImmutableMap.of("detect-drivers", "true", "delete-session-on-ui", "true")));
+            singletonMap("node", Map.of("detect-drivers", "true", "delete-session-on-ui", "true")));
 
     List<Capabilities> reported = new ArrayList<>();
     new NodeOptions(config)
@@ -831,8 +822,7 @@ class NodeOptionsTest {
     Config config =
         new MapConfig(
             singletonMap(
-                "node",
-                ImmutableMap.of("detect-drivers", "true", "delete-session-on-ui", "false")));
+                "node", Map.of("detect-drivers", "true", "delete-session-on-ui", "false")));
 
     List<Capabilities> reported = new ArrayList<>();
     new NodeOptions(config)
