@@ -17,14 +17,18 @@
 
 package org.openqa.selenium.grid.router;
 
+import static java.util.Objects.requireNonNull;
+import static java.util.logging.Level.FINE;
+import static java.util.logging.Level.INFO;
 import static org.assertj.core.api.Assertions.assertThat;
 
 import java.io.StringReader;
-import java.util.Objects;
+import java.net.URL;
 import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.TimeoutException;
+import java.util.logging.Logger;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
@@ -49,12 +53,15 @@ import org.openqa.selenium.testing.Safely;
 import org.openqa.selenium.testing.drivers.Browser;
 
 class RemoteWebDriverBiDiTest extends JupiterTestBase {
+  private static final Logger LOG = Logger.getLogger(RemoteWebDriverBiDiTest.class.getName());
 
   private Deployment deployment;
+  private URL remoteUrl;
 
   @BeforeEach
   void setup() {
-    Browser browser = Objects.requireNonNull(Browser.detect());
+    Browser browser = requireNonNull(Browser.detect());
+    LOG.log(FINE, () -> String.format("Starting grid server for %s...", browser));
 
     deployment =
         DeploymentTypes.STANDALONE.start(
@@ -65,23 +72,29 @@ class RemoteWebDriverBiDiTest extends JupiterTestBase {
                         + "selenium-manager = false\n"
                         + "driver-implementation = "
                         + String.format("\"%s\"", browser.displayName()))));
-  }
+    remoteUrl = deployment.getServer().getUrl();
+    LOG.log(INFO, () -> String.format("Started grid server for %s: %s", browser, remoteUrl));
 
-  private void createDriver() {
-    Browser browser = Objects.requireNonNull(Browser.detect());
-    localDriver = new RemoteWebDriver(deployment.getServer().getUrl(), browser.getCapabilities());
+    localDriver = new RemoteWebDriver(remoteUrl, browser.getCapabilities());
     localDriver = new Augmenter().augment(localDriver);
   }
 
   @AfterEach
   void tearDownDeployment() {
-    Safely.safelyCall(() -> deployment.tearDown());
+    if (localDriver != null) {
+      localDriver.quit();
+    }
+
+    if (deployment != null) {
+      LOG.log(FINE, () -> String.format("Stopping grid server %s ...", remoteUrl));
+      Safely.safelyCall(() -> deployment.tearDown());
+      LOG.log(INFO, () -> String.format("Stopped grid server %s", remoteUrl));
+    }
   }
 
   @Test
   @NoDriverBeforeTest
   void ensureBiDiSessionCreation() {
-    createDriver();
     try (BiDi biDi = ((HasBiDi) localDriver).getBiDi()) {
       BiDiSessionStatus status = biDi.getBidiSessionStatus();
       assertThat(status).isNotNull();
@@ -92,7 +105,6 @@ class RemoteWebDriverBiDiTest extends JupiterTestBase {
   @Test
   @NoDriverBeforeTest
   void canListenToLogs() throws ExecutionException, InterruptedException, TimeoutException {
-    createDriver();
     try (LogInspector logInspector = new LogInspector(localDriver)) {
       CompletableFuture<ConsoleLogEntry> future = new CompletableFuture<>();
       logInspector.onConsoleEntry(future::complete);
@@ -117,7 +129,6 @@ class RemoteWebDriverBiDiTest extends JupiterTestBase {
   @Test
   @NoDriverBeforeTest
   void canNavigateToUrl() {
-    createDriver();
     BrowsingContext browsingContext = new BrowsingContext(localDriver, WindowType.TAB);
 
     String url = appServer.whereIs("/bidi/logEntryAdded.html");
