@@ -246,7 +246,7 @@ class CombinedInputActionsTest extends JupiterTestBase {
     wait.until(presenceOfElementLocated(By.id("ifr")));
     driver.switchTo().frame("ifr");
 
-    WebElement link = driver.findElement(By.id("link"));
+    WebElement link = wait.until(presenceOfElementLocated(By.id("link")));
 
     new Actions(driver).moveToElement(link).click().perform();
 
@@ -299,13 +299,6 @@ class CombinedInputActionsTest extends JupiterTestBase {
     assertThat(y).isCloseTo(location.getY() + 10, Offset.offset(5));
   }
 
-  private boolean fuzzyPositionMatching(int expectedX, int expectedY, int actualX, int actualY) {
-    // Everything within 5 pixels range is OK
-    final int ALLOWED_DEVIATION = 5;
-    return Math.abs(expectedX - actualX) < ALLOWED_DEVIATION
-        && Math.abs(expectedY - actualY) < ALLOWED_DEVIATION;
-  }
-
   /**
    * This test demonstrates the following problem: When the representation of the mouse in the
    * driver keeps the wrong state, mouse movement will end up at the wrong coordinates.
@@ -388,7 +381,7 @@ class CombinedInputActionsTest extends JupiterTestBase {
 
   @Test
   @NotYetImplemented(SAFARI)
-  public void canClickOnASuckerFishStyleMenu() throws InterruptedException {
+  public void canClickOnASuckerFishStyleMenu() {
     driver.get(pages.javascriptPage);
     unfocusMenu();
 
