@@ -28,6 +28,7 @@ import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import org.jspecify.annotations.NonNull;
 import org.junit.jupiter.api.Tag;
 import org.junit.jupiter.api.Test;
 import org.openqa.selenium.By;
@@ -114,8 +115,7 @@ class AugmenterTest {
     // This will force the class to be enhanced
     final Capabilities caps = new ImmutableCapabilities("magic.numbers", true);
 
-    DetonatingDriver driver = new DetonatingDriver();
-    driver.setCapabilities(caps);
+    DetonatingDriver driver = new DetonatingDriver(caps);
 
     WebDriver returned =
         getAugmenter()
@@ -337,12 +337,17 @@ class AugmenterTest {
 
   public static class DetonatingDriver extends RemoteWebDriver {
 
-    private Capabilities caps;
+    private final Capabilities caps;
 
-    public void setCapabilities(Capabilities caps) {
+    protected DetonatingDriver() {
+      this(null);
+    }
+
+    public DetonatingDriver(Capabilities caps) {
       this.caps = caps;
     }
 
+    @NonNull
     @Override
     public Capabilities getCapabilities() {
       return caps;
@@ -366,6 +371,7 @@ class AugmenterTest {
 
   public static class ChildRemoteDriver extends RemoteWebDriver implements HasMagicNumbers {
 
+    @NonNull
     @Override
     public Capabilities getCapabilities() {
       return new FirefoxOptions();
@@ -379,6 +385,7 @@ class AugmenterTest {
 
   public static class WithFinals extends RemoteWebDriver {
 
+    @NonNull
     @Override
     public Capabilities getCapabilities() {
       return new ImmutableCapabilities();
