@@ -162,10 +162,6 @@ public class TestUtilities {
         || Boolean.getBoolean("selenium.browser.grid"));
   }
 
-  public static boolean isOnTravis() {
-    return Boolean.parseBoolean(System.getenv("TRAVIS"));
-  }
-
   public static boolean isOnGitHubActions() {
     return Boolean.parseBoolean(System.getenv("GITHUB_ACTIONS"));
   }
