@@ -84,16 +84,21 @@ module Selenium
           wait.until { driver.title }
         end
 
-        def wait_for_element(locator)
-          wait = Wait.new(timeout: 25, ignore: Error::NoSuchElementError)
+        def wait_for_element(locator, timeout = 25)
+          wait = Wait.new(timeout: timeout, ignore: Error::NoSuchElementError, message_provider: lambda {
+            url = "page url: #{driver.current_url};\n"
+            source = "page source: #{driver.find_element(css: 'body').attribute('innerHTML')}\n"
+            "could not find element #{locator} in #{timeout} seconds;\n#{url}#{source}"
+          })
           wait.until { driver.find_element(locator) }
         end
 
-        def wait_for_new_url(old_url)
-          wait = Wait.new(timeout: 5)
+        def wait_for_url(new_url, timeout = 15)
+          wait = Wait.new(timeout: timeout, message_provider: lambda {
+            "could not wait for URL #{new_url} in #{timeout} seconds;\nactual page url: #{driver.current_url};\n"
+          })
           wait.until do
-            url = driver.current_url
-            !(url.empty? || url.include?(old_url))
+            driver.current_url.include?(new_url)
           end
         end
 
@@ -102,6 +107,18 @@ module Selenium
           wait.until { driver.devtools(target_type: target_type).target }
         end
 
+        def wait_for_title(title:)
+          wait = Wait.new(timeout: 15)
+          wait.until { driver.title == title }
+        end
+
+        def open_file(file_name)
+          driver.navigate.to 'about:blank'
+          driver.navigate.to url_for('blank.html')
+          driver.navigate.to url_for(file_name)
+          wait_for_url(file_name)
+        end
+
         def wait(timeout = 10)
           Wait.new(timeout: timeout)
         end
